| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Graphics.GPipe.Context.GLFW.Unsafe
Description
Exposes some underlying implementation details which can be used to
gain access to GLFW functionality that isn't exposed by this
library otherwise, but which can be dangerous if used incorrectly.
The underlying Window object can be retrieved from a
GLFWWindow using getGLFWWindow.It can be used inside a
ContextT as follows:
withContextWindow (\win -> doSomething (getGLFWWindow win))
Bear in mind that it is possible to do bad things with this. For example, using
makeContextCurrent could cause GPipe to lose control of the window,
and destroyWindow is bad for obvious reasons.
See Input for concrete examples.
- newtype GLFWWindow = GLFWWindow {}
Documentation
newtype GLFWWindow Source #
A value representing a GLFW OpenGL context window.
Constructors
| GLFWWindow | |
Fields | |