| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Graphics.GPipe.Context.GLFW.Wrapped
Description
Wrapped calls to GLFW-b for application programmer use. For user input see Graphics.GPipe.Context.GLFW.Input.
Actions are in the GPipe ContextT monad when a window handle is required,
otherwise they are bare reexported IO actions which can be lifted into the ContextT monad.
The Window taken by many of these functions is the window resource from GPipe.